import React from 'react';
import classnames from 'classnames';
import get from 'lodash/get';

import styles from './styles.scss';

const useNavigator = () => {
  if (typeof window === 'undefined') {
    return false;
  } else {
    return /iPad|iPhone|iPod|Android/.test(navigator.userAgent) && !window.MSStream;
  }
};

class Share extends React.PureComponent {
  getCanonical = () => {
    return (
      document.querySelector('link[rel=canonical]') &&
      document.querySelector('link[rel=canonical]').href
    ) || window.location.href;
  }

  getTitle = () => {
    return (
      document.querySelector('meta[property="og:title"]') &&
      document.querySelector('meta[property="og:title"]').getAttribute('content')
    ) || (
      document.querySelector('meta[property="twitter:title"]') &&
      document.querySelector('meta[property="twitter:title"]').getAttribute('content')
    ) || (
      document.querySelector('title') &&
      document.querySelector('title').innerText
    ) || '';
  }

  getStatus = () => {
    const tweetText = get(this.props, 'tweet', '');
    const uri = window.location.href;
    return encodeURIComponent(`${tweetText}\n\n${uri}`);
  }

  navigatorShare = () => {
    if (useNavigator() && navigator.share) {
      navigator.share({
        title: this.getTitle(),
        url: this.getCanonical(),
      }).catch(e => {});
      return true;
    } else {
      return false;
    }
  }

  fbHandlder = e => {
    e.preventDefault();
    this.props.onFb();

    if (!this.navigatorShare()) {
      const u = encodeURIComponent(window.location.href);
      window.open(`https://www.facebook.com/sharer/sharer.php?u=${u}`);
    }
  }

  mailHandler = e => {
    this.props.onMail();
    if (this.navigatorShare()) {
      e.preventDefault();
    }
  }

  twitterHandler = e => {
    e.preventDefault();
    this.props.onTwitter();

    if (!this.navigatorShare()) {
      const status = this.getStatus();
      window.open(`https://twitter.com/intent/tweet?text=${status}`);
    }
  }

  render() {
    const subject = encodeURIComponent(this.props.subject);

    const status = typeof window === 'undefined' ? '' : this.getStatus();

    return (
      <div className={classnames('share', styles.styles)}>
        <a href='' className='bt-icon custom-icon--facebook' target='_blank' onClick={this.fbHandlder}>
          <svg version='1.1' xmlns='http://www.w3.org/2000/svg' xlinkHref='http://www.w3.org/1999/xlink' width='14' height='14' fill='white' viewBox='0 0 15 15'>
            <path d='M9.229 15.988h-3.305v-7.989h-1.652v-2.754h1.652v-1.653c0-2.246 0.932-3.582 3.581-3.582h2.206v2.754h-1.378c-1.031 0-1.1 0.385-1.1 1.103l-0.004 1.378h2.498l-0.292 2.754h-2.206v7.989z' />
          </svg>
        </a>
        <a href='' className='bt-icon bt-icon--twitter' target='_blank' onClick={this.twitterHandler} />
        <a href={`mailto:?subject=${subject}&body=${status}`} className='bt-icon bt-icon--mail' target='_blank' onClick={this.mailHandler} />
      </div>
    );
  }
}

Share.defaultProps = {
  subject: '',
  tweet: '',
  onFb: () => {},
  onTwitter: () => {},
  onMail: () => {},
};

export default Share;

export const activateSocialButtons = props => {
  const tweetText = get(props, 'tweet', '');
  const uri = window.location.href;
  const status = encodeURIComponent(`${tweetText}\n\n${uri}`);
  const subject = encodeURIComponent(get(props, 'subject', ''));

  document.querySelector('.custom-icon--facebook').addEventListener('click', (e) => {
    e.preventDefault();
    const u = encodeURIComponent(uri);
    window.open(`https://www.facebook.com/sharer/sharer.php?u=${u}`);
  });

  document.querySelector('.bt-icon--twitter').addEventListener('click', (e) => {
    e.preventDefault();
    window.open(`https://twitter.com/intent/tweet?text=${status}`);
  });

  const mailIcon = document.querySelector('.bt-icon--mail');
  mailIcon.target = '';
  mailIcon.href = `mailto:?subject=${subject}&body=${status}`;
};
